@@ -5,6 +5,7 @@ const St = imports.gi.St;
 const Main = imports.ui.main;
 const PopupMenu = imports.ui.popupMenu;
 const GnomeSession = imports.misc.gnomeSession;
+const UserMenu = imports.ui.userMenu;
 
 const Gettext = imports.gettext.domain('gnome-shell-extensions');
 const _ = Gettext.gettext;
@@ -36,21 +37,20 @@ function onHibernateActivate(item) {
 function createSubMenu() {
     let item;
 
-    item = new PopupMenu.PopupImageMenuItem(_("Available"), 'user-available');
-    item.connect('activate', Lang.bind(this, this._setPresenceStatus, GnomeSession.PresenceStatus.AVAILABLE));
+    item = new UserMenu.IMStatusChooserItem();
+    item.connect('activate', Lang.bind(this, this._onMyAccountActivate));
     this.menu.addMenuItem(item);
-    this._presenceItems[GnomeSession.PresenceStatus.AVAILABLE] = item;
 
-    item = new PopupMenu.PopupImageMenuItem(_("Busy"), 'user-busy');
-    item.connect('activate', Lang.bind(this, this._setPresenceStatus, GnomeSession.PresenceStatus.BUSY));
+    item = new PopupMenu.PopupSwitchMenuItem(_("Notifications"));
+    item.connect('activate', Lang.bind(this, this._updatePresenceStatus));
     this.menu.addMenuItem(item);
-    this._presenceItems[GnomeSession.PresenceStatus.BUSY] = item;
+    this._notificationsSwitch = item;
 
     item = new PopupMenu.PopupSeparatorMenuItem();
     this.menu.addMenuItem(item);
 
-    item = new PopupMenu.PopupMenuItem(_("My Account"));
-    item.connect('activate', Lang.bind(this, this._onMyAccountActivate));
+    item = new PopupMenu.PopupMenuItem(_("Online Accounts"));
+    item.connect('activate', Lang.bind(this, this._onOnlineAccountsActivate));
     this.menu.addMenuItem(item);
 
     item = new PopupMenu.PopupMenuItem(_("System Settings"));
@@ -63,6 +63,7 @@ function createSubMenu() {
     item = new PopupMenu.PopupMenuItem(_("Lock Screen"));
     item.connect('activate', Lang.bind(this, this._onLockScreenActivate));
     this.menu.addMenuItem(item);
+    this._lockScreenItem = item;
 
     item = new PopupMenu.PopupMenuItem(_("Switch User"));
     item.connect('activate', Lang.bind(this, this._onLoginScreenActivate));
@@ -72,6 +73,7 @@ function createSubMenu() {
     item = new PopupMenu.PopupMenuItem(_("Log Out..."));
     item.connect('activate', Lang.bind(this, this._onQuitSessionActivate));
     this.menu.addMenuItem(item);
+    this._logoutItem = item;
 
     item = new PopupMenu.PopupSeparatorMenuItem();
     this.menu.addMenuItem(item);
@@ -96,10 +98,32 @@ function createSubMenu() {
 }
 
 // Put your extension initialization code here
-function main(metadata) {
+function init(metadata) {
     imports.gettext.bindtextdomain('gnome-shell-extensions', metadata.localedir);
+}
 
-    let statusMenu = Main.panel._userMenu;
+function reset(statusMenu) {
+    statusMenu._updateSwitchUser();
+    statusMenu._updateLogout();
+    statusMenu._updateLockScreen();
+
+    statusMenu._presence.getStatus(Lang.bind(statusMenu, statusMenu._updateSwitch));
+
+    // HACK! Obtain the IMStatusChooserItem and force a _updateUser
+    statusMenu.menu._getMenuItems()[0]._updateUser();
+}
+
+function enable() {
+    let statusMenu = Main.panel._statusArea.userMenu;
     statusMenu.menu.removeAll();
     createSubMenu.call(statusMenu);
+    reset(statusMenu);
 }
+
+function disable() {
+    // not guarranteed to work, if more extensions operate in the same place
+    let statusMenu = Main.panel._statusArea.userMenu;
+    statusMenu.menu.removeAll();
+    statusMenu._createSubMenu();
+    reset(statusMenu);
+}
\ No newline at end of file
